@@ -1,16 +1,18 @@
-#line 9382 "../../doc/bison.texinfo"
+#line 9923 "../../doc/bison.texi"
 #include <iostream>
 #include "calc++-driver.hh"
 
+
 int
 main (int argc, char *argv[])
 {
   calcxx_driver driver;
-  for (++argv; argv[0]; ++argv)
-    if (*argv == std::string ("-p"))
+  for (int i = 1; i < argc; ++i)
+    if (argv[i] == std::string ("-p"))
       driver.trace_parsing = true;
-    else if (*argv == std::string ("-s"))
+    else if (argv[i] == std::string ("-s"))
       driver.trace_scanning = true;
-    else if (!driver.parse (*argv))
+    else if (!driver.parse (argv[i]))
       std::cout << driver.result << std::endl;
 }
+
